/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import {
	assembleMethodSymbol,
	registerCustomElement,
} from "../../dom/customelement.mjs";
import { EmbeddedPaginationStyleSheet } from "./stylesheet/embedded-pagination.mjs";
import { instanceSymbol } from "../../constants.mjs";

import "../form/select.mjs";
import { Pagination } from "./pagination.mjs";

import "./datasource/dom.mjs";
import "./datasource/rest.mjs";

export { EmbeddedPagination };

/**
 * The EmbeddedPagination component is used to show the current page and the total number of pages.
 *
 * @copyright schukai GmbH
 * @summary The EmbeddedPagination extends the Pagination component and adopts the styles of the DataTable component.
 */
class EmbeddedPagination extends Pagination {
	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 */
	static get [instanceSymbol]() {
		return Symbol.for(
			"@schukai/monster/components/datatable/embedded-pagination",
		);
	}

	/**
	 * @private
	 */
	[assembleMethodSymbol]() {
		super[assembleMethodSymbol]();
	}

	/**
	 *
	 * @property {Object} classes Class definitions
	 * @property {string} classes.spinner Spinner class
	 * @property {string} classes.spinnerContainer Spinner container class
	 * @property {string} classes.error Error class
	 * @property {string} classes.errorContainer Error container class
	 */
	get defaults() {
		return Object.assign({}, super.defaults, {
			classes: {
				spinner: "monster-spinner monster-theme-primary-3",
				spinnerContainer: "monster-theme-primary-2 ",
				error: "monster-theme-error-2 monster-bg-color-primary-2",
				errorContainer: "monster-theme-primary-2",
			},
		});
	}

	/**
	 *
	 * @return {string}
	 */
	static getTag() {
		return "monster-embedded-pagination";
	}

	/**
	 * @private
	 * @return {CSSStyleSheet}
	 */
	static getControlCSSStyleSheet() {
		return EmbeddedPaginationStyleSheet;
	}
}

registerCustomElement(EmbeddedPagination);
