/**
 * Copyright © schukai GmbH and all contributing authors, 2025. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 */

import { addAttributeToken } from "../../dom/attributes.mjs";
import { ATTRIBUTE_ERRORMESSAGE } from "../../dom/constants.mjs";

export { CommonStyleSheet };

/**
 * @private
 * @type {CSSStyleSheet}
 */
const CommonStyleSheet = new CSSStyleSheet();

try {
	CommonStyleSheet.insertRule(
		`
@layer common { 
a,abbr,acronym,address,applet,article,aside,audio,b,big,blockquote,body,canvas,caption,center,cite,code,dd,del,details,dfn,div,dl,dt,em,embed,fieldset,figcaption,figure,footer,form,h1,h2,h3,h4,h5,h6,header,hgroup,html,i,iframe,img,ins,kbd,label,legend,li,mark,menu,nav,object,ol,output,p,pre,q,ruby,s,samp,section,small,span,strike,strong,sub,summary,sup,table,tbody,td,tfoot,th,thead,time,tr,tt,u,ul,var,video{border:0;font-size:100%;font:inherit;margin:0;padding:0;vertical-align:baseline}*{box-sizing:border-box;font-family:var(--monster-font-family,-apple-system,BlinkMacSystemFont,\"Segoe UI\",Roboto,Oxygen-Sans,Ubuntu,Cantarell,\"Helvetica Neue\",sans-serif)}.visible{tvisibility:visible!important}.invisible{visibility:hidden!important}.hidden{display:none!important}.inline{display:inline!important}.block{display:block!important}.flex{display:flex!important}[data-monster-role=control]{outline:none}div[data-monster-role=popper]{background-color:#fff;border:var(--monster-border-width,1px) solid var(--monster-color-primary-1);box-sizing:border-box;display:none;padding:0;z-index:10}:host([disabled]){background-color:var(--monster-bg-color-primary-disabled-1);border-color:var(--monster-color-primary-disabled-1,hsla(0,0%,46%,.3));color:var(--monster-color-primary-disabled-1)}:host([disabled]) *{background-color:var(--monster-bg-color-primary-disabled-1);border-color:var(--monster-color-primary-disabled-1,hsla(0,0%,46%,.3));color:var(--monster-color-primary-disabled-1)}:disabled{background-color:var(--monster-bg-color-primary-disabled-1);border-color:var(--monster-color-primary-disabled-1,hsla(0,0%,46%,.3));color:var(--monster-color-primary-disabled-1);cursor:not-allowed;opacity:.55;pointer-events:none}input:focus-visible{outline:none}body:focus-visible{outline:none}:focus-visible{outline:none} 
}`,
		0,
	);
} catch (e) {
	addAttributeToken(
		document.getRootNode().querySelector("html"),
		ATTRIBUTE_ERRORMESSAGE,
		e + "",
	);
}
