/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { AbstractConstraint } from "./abstract.mjs";
import { instanceSymbol } from "../constants.mjs";
export { AbstractOperator };

/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * Operators allow you to link constraints together. for example, you can check whether a value is
 * an object or an array. each operator has two operands that are linked together.
 *
 * @license AGPLv3
 * @since 1.3.0
 * @copyright schukai GmbH
 * @summary The abstract operator constraint
 */
class AbstractOperator extends AbstractConstraint {
	/**
	 *
	 * @param {AbstractConstraint} operantA
	 * @param {AbstractConstraint} operantB
	 * @throws {TypeError} "parameters must be from type AbstractConstraint"
	 */
	constructor(operantA, operantB) {
		super();

		if (
			!(
				operantA instanceof AbstractConstraint &&
				operantB instanceof AbstractConstraint
			)
		) {
			throw new TypeError("parameters must be from type AbstractConstraint");
		}

		this.operantA = operantA;
		this.operantB = operantB;
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 * @since 2.1.0
	 */
	static get [instanceSymbol]() {
		return Symbol.for("@schukai/monster/constraints/abstract-operator");
	}
}
