/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { AbstractOperator } from "./abstractoperator.mjs";
import { instanceSymbol } from "../constants.mjs";
export { AndOperator };

/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * The AndOperator is used to link several constraints. The constraint is fulfilled if all constraints of the operators are fulfilled.
 *
 * @example /examples/libraries/constraints/andoperator/ A simple example
 *
 * @license AGPLv3
 * @since 1.3.0
 * @copyright schukai GmbH
 * @summary A and operator constraint
 */
class AndOperator extends AbstractOperator {
	/**
	 * This method returns a promise containing the result of the check.
	 *
	 * @param {*} value
	 * @return {Promise}
	 */
	isValid(value) {
		return Promise.all([
			this.operantA.isValid(value),
			this.operantB.isValid(value),
		]);
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 * @since 2.1.0
	 */
	static get [instanceSymbol]() {
		return Symbol.for("@schukai/monster/constraints/and-operator");
	}
}
