/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { AbstractConstraint } from "./abstract.mjs";
import { instanceSymbol } from "../constants.mjs";
export { Invalid };

/**
 * Constraints are used to define conditions that must be met by the value of a variable.
 *
 * The uniform API of the constraints allows chains to be formed.
 *
 * The invalid constraint allows an always invalid query to be performed. this constraint is mainly intended for testing.
 *
 * @example /examples/libraries/constraints/invalid/ A simple example
 *
 * @license AGPLv3
 * @since 1.3.0
 * @copyright schukai GmbH
 * @summary A constraint that always invalid
 */
class Invalid extends AbstractConstraint {
	/**
	 * this method returns a rejected promise
	 *
	 * @param {*} value
	 * @return {Promise}
	 */
	isValid(value) {
		return Promise.reject(value);
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 * @since 2.1.0
	 */
	static get [instanceSymbol]() {
		return Symbol.for("@schukai/monster/constraints/invalid");
	}
}
