/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { internalSymbol, instanceSymbol } from "../../../../constants.mjs";

export { DataFetchError };

/**
 * Error message for API requests
 *
 * @license AGPLv3
 * @since 3.43.0
 * @copyright schukai GmbH
 * @summary the error is thrown by the rest api in case of error
 */
class DataFetchError extends Error {
	/**
	 *
	 * @param {string} message
	 * @param {Response} response
	 */
	constructor(message, response) {
		super(message);

		let body = null;

		if (response instanceof Response) {
			body = response.text();
		}

		if (!(body instanceof Promise)) {
			body = Promise.resolve(body);
		}

		this[internalSymbol] = {
			response: response,
			body: body,
		};
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 */
	static get [instanceSymbol]() {
		return Symbol.for(
			"@schukai/monster/data/datasource/server/restapi/datafetcherror@@instance",
		);
	}

	/**
	 * @return {string|Object}
	 */
	getBody() {
		return this[internalSymbol]?.["body"];
	}

	/**
	 * @return {Response}
	 */
	getResponse() {
		return this[internalSymbol]?.["response"];
	}
}
