/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { internalSymbol, instanceSymbol } from "../../../../constants.mjs";

export { WriteError };

/**
 * Error message for API requests with extension of request and validation.
 *
 * @license AGPLv3
 * @since 1.24.0
 * @copyright schukai GmbH
 * @summary the error is thrown by the rest api in case of error
 */
class WriteError extends Error {
	/**
	 *
	 * @param {string} message
	 * @param {Response} response
	 * @param {Object} validation
	 */
	constructor(message, response, validation) {
		super(message);
		this[internalSymbol] = {
			response: response,
			validation: validation,
		};
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 * @since 2.1.0
	 */
	static get [instanceSymbol]() {
		return Symbol.for(
			"@schukai/monster/data/datasource/server/restapi/write-error",
		);
	}

	/**
	 * @return {Response}
	 */
	getResponse() {
		return this[internalSymbol]["response"];
	}

	/**
	 * @return {Object}
	 */
	getValidation() {
		return this[internalSymbol]["validation"];
	}
}
