/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { internalSymbol, instanceSymbol } from "../../../constants.mjs";
import { getGlobalObject } from "../../../types/global.mjs";
import { Datasource } from "../../datasource.mjs";
import { Storage, storageObjectSymbol } from "../storage.mjs";

export { LocalStorage };

/**
 * The LocalStorage Datasource provides a data store in the browser localStorage.
 *
 * @license AGPLv3
 * @since 1.22.0
 * @copyright schukai GmbH
 * @summary The LocalStorage class encapsulates the access to data objects.
 */
class LocalStorage extends Storage {
	/**
	 * @throws {Error} this method must be implemented by derived classes.
	 * @return {external:localStorage}
	 * @private
	 */
	[storageObjectSymbol]() {
		return getGlobalObject("localStorage");
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 * @since 2.1.0
	 */
	static get [instanceSymbol]() {
		return Symbol.for("@schukai/monster/data/datasource/storage/localstorage");
	}

	/**
	 * Create clone
	 * @return {LocalStorage}
	 */
	getClone() {
		return new LocalStorage(
			this[internalSymbol].getRealSubject()["options"].key,
		);
	}
}
