/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { extend } from "../../../data/extend.mjs";
import { Link } from "../link.mjs";
import { instanceSymbol } from "../../../constants.mjs";
export { Stylesheet };

/**
 * This class is used by the resource manager to embed external resources.
 *
 * @license AGPLv3
 * @since 1.25.0
 * @copyright schukai GmbH
 * @summary A Resource class
 * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link
 */
class Stylesheet extends Link {
	/**
	 * @property {string} rel {@link https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link#attr-rel}
	 */
	get defaults() {
		return extend({}, super.defaults, {
			rel: "stylesheet",
		});
	}

	/**
	 * This method is called by the `instanceof` operator.
	 * @return {symbol}
	 * @since 2.1.0
	 */
	static get [instanceSymbol]() {
		return Symbol.for("@schukai/monster/dom/resource/link/stylesheet");
	}
}
