/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { Base } from "../types/base.mjs";
import { validateInteger } from "../types/validate.mjs";

export { LogEntry };

/**
 * A log entry for the logger
 *
 * @license AGPLv3
 * @since 1.5.0
 * @copyright schukai GmbH
 */
class LogEntry extends Base {
	/**
	 *
	 * @param {Integer} loglevel
	 * @param {...*} args
	 */
	constructor(loglevel, ...args) {
		super();
		validateInteger(loglevel);

		this.loglevel = loglevel;
		this.arguments = args;
	}

	/**
	 *
	 * @return {integerr}
	 */
	getLogLevel() {
		return this.loglevel;
	}

	/**
	 *
	 * @return {array}
	 */
	getArguments() {
		return this.arguments;
	}
}
