/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { validateString } from "./validate.mjs";

export { toBinary, fromBinary };

/**
 * You can call the function via the monster namespace `Monster.Types.toBinary()`.
 *
 * @param {String} binary
 * @return {String}
 * @throws {TypeError} value is not a string
 * @license AGPLv3
 * @since 1.18.0
 */
function toBinary(string) {
	const codeUnits = new Uint16Array(validateString(string).length);
	for (let i = 0; i < codeUnits.length; i++) {
		codeUnits[i] = string.charCodeAt(i);
	}

	const charCodes = new Uint8Array(codeUnits.buffer);
	let result = "";

	for (let i = 0; i < charCodes.byteLength; i++) {
		result += String.fromCharCode(charCodes[i]);
	}

	return result;
}

/**
 * You can call the function via the monster namespace `Monster.Types.fromBinary()`.
 *
 * @param {String} binary
 * @return {String}
 * @throws {TypeError} value is not a string
 * @license AGPLv3
 * @since 1.18.0
 */
function fromBinary(binary) {
	const bytes = new Uint8Array(validateString(binary).length);
	for (let i = 0; i < bytes.length; i++) {
		bytes[i] = binary.charCodeAt(i);
	}
	const charCodes = new Uint16Array(bytes.buffer);
	let result = "";
	for (let i = 0; i < charCodes.length; i++) {
		result += String.fromCharCode(charCodes[i]);
	}
	return result;
}
