/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { Base } from "./base.mjs";
import { Observer } from "./observer.mjs";
import { validateInstance } from "./validate.mjs";

export { ObserverList };

/**
 * With the help of the ObserverList class, observer can be managed.
 *
 * @license AGPLv3
 * @since 1.0.0
 */
class ObserverList extends Base {
	/**
	 *
	 */
	constructor() {
		super();
		this.observers = [];
	}

	/**
	 *
	 * @param {Observer} observer
	 * @return {ObserverList}
	 * @throws {TypeError} value is not an instance of Observer
	 */
	attach(observer) {
		validateInstance(observer, Observer);

		this.observers.push(observer);
		return this;
	}

	/**
	 *
	 * @param {Observer} observer
	 * @return {ObserverList}
	 * @throws {TypeError} value is not an instance of Observer
	 */
	detach(observer) {
		validateInstance(observer, Observer);

		var i = 0;
		var l = this.observers.length;
		for (; i < l; i++) {
			if (this.observers[i] === observer) {
				this.observers.splice(i, 1);
			}
		}

		return this;
	}

	/**
	 *
	 * @param {Observer} observer
	 * @return {boolean}
	 * @throws {TypeError} value is not an instance of Observer
	 */
	contains(observer) {
		validateInstance(observer, Observer);
		var i = 0;
		var l = this.observers.length;
		for (; i < l; i++) {
			if (this.observers[i] === observer) {
				return true;
			}
		}
		return false;
	}

	/**
	 *
	 * @param subject
	 * @return {Promise}
	 */
	notify(subject) {
		const pomises = [];

		let i = 0;
		const l = this.observers.length;
		for (; i < l; i++) {
			pomises.push(this.observers[i].update(subject));
		}

		return Promise.all(pomises);
	}
}
