/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { random } from "../math/random.mjs";
import { getGlobal } from "./global.mjs";
import { ID } from "./id.mjs";

export { RandomID };

/**
 * @private
 * @type {number}
 */
let internalCounter = 0;

/**
 * The `RandomID` class provides a unique ID for an item.
 *
 * @license AGPLv3
 * @since 1.6.0
 * @copyright schukai GmbH
 * @summary class to generate random numbers
 */
class RandomID extends ID {
	/**
	 * create new object
	 */
	constructor() {
		super();

		internalCounter += 1;

		this.id =
			getGlobal()
				.btoa(random(1, 10000))
				.replace(/=/g, "")
				/** No numbers at the beginning of the ID, because of possible problems with DOM */
				.replace(/^[0-9]+/, "X") + internalCounter;
	}
}
