/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

export { typeOf };

/**
 * The built-in typeof method is known to have some historical weaknesses. This function tries to provide a better and more accurate result.
 *
 * @param {*} value
 * @return {string}
 * @license AGPLv3
 * @since 1.7.0
 * @copyright schukai GmbH
 * @throws {TypeError} value is not a primitive
 */
function typeOf(value) {
	let type = {}.toString.call(value).match(/\s([a-zA-Z]+)/)[1];
	if ("Object" === type) {
		const name = value.constructor.name;
		if (name) {
			return name.toLowerCase();
		}

		const results = /^(class|function)\s+(\w+)/.exec(
			value.constructor.toString(),
		);
		type = results && results.length > 2 ? results[2] : "";
	}

	return type.toLowerCase();
}
