/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { validateObject } from "../types/validate.mjs";

export { deepFreeze };

/**
 * Deep freeze a object
 *
 * @param {object} object object to be freeze
 * @license AGPLv3
 * @since 1.0.0
 * @return {object}
 * @copyright schukai GmbH
 * @throws {TypeError} value is not a object
 */
function deepFreeze(object) {
	validateObject(object);

	// Retrieve the defined property names of the object
	let propNames = Object.getOwnPropertyNames(object);

	// Freeze properties before freezing yourself
	for (const name of propNames) {
		const value = object[name];

		object[name] =
			value && typeof value === "object" ? deepFreeze(value) : value;
	}

	return Object.freeze(object);
}
